Check the data files and measure info of subprojects.
Value
A list with an entry for each source, containing a character vector including any issue codes:
not_compressed: The file does not appear to be compressed.cant_read: Failed to read the file in.geography_nas: The file'sgeographycolumn contains NAs.geography_dropped: The file'sgeographycolumn has levels dropped from previous versions.time_nas: The file'stimecolumn contains NAs.missing_info: {column_name}: The file's indicated column does not have a matching entry inmeasure_info.json.dropped_measure: {column_name}: The file's indicated column is not present when it was previously.type_changed: {column_name}: The file's indicated column's type changed from the previous version.