Skip to contents

Retrieve the report file from a local or remote project.

Usage

dcf_report(
  project = "dissc-yale/pophive_demo",
  branch = "main",
  commit = NULL,
  provider = "https://github.com",
  cache = tempdir(),
  refresh = FALSE
)

Arguments

project

Path to a local project, or the GitHub account and repository name ("{account_name}/{repo_name}") of a remote project.

branch

Name of the remote repository branch.

commit

Commit hash; overrides branch.

provider

Base URL of the remote repository provider.

cache

Directory to store retrieved report in (at {cache}/{project}/report.json.gz).

refresh

Logical; if TRUE, will always retrieve a fresh copy of the report, even if a copy exists in cache.

Value

A data collection project report:

dateTimestamp when the report was created.
settingsThe project's settings file.
source_timesA list with entries for each subproject, containing the number of seconds it took to run the project's scripts.
issuesA list with entries for each subproject, containing issues flagged by dcf_check, within a list with data and/or measure entries, containing character vectors of issue labels.
logsA list with entries for each subproject, containing the logged output of their scripts.
metadataA list with entries for each subproject, containing the datapackage of their output, as created by dcf_measure_info.
processesA list with entries for each subproject, containing their process definitions (see dcf_add_source and/or dcf_add_bundle).

See also

Other data user interface functions: dcf_data(), dcf_variables()

Examples

report <- dcf_report("dissc-yale/pophive_demo")
report$date
#> [1] "2026-03-22 03:06:42"
jsonlite::toJSON(report$settings, auto_unbox = TRUE, pretty = TRUE)
#> {
#>   "name": "pophive",
#>   "data_dir": "data",
#>   "github_account": "dissc-yale",
#>   "branch": "main",
#>   "repo_name": "pophive_demo",
#>   "report_url": "https://github.com/dissc-yale/pophive_demo/raw/refs/heads/main/report.json.gz"
#> }